@@ -27,6 +27,7 @@ from pypika.utils import (
 class SnowFlakeQueryBuilder(QueryBuilder):
     QUOTE_CHAR = None
     ALIAS_QUOTE_CHAR = '"'
+    QUERY_ALIAS_QUOTE_CHAR = ''
 
     def __init__(self, **kwargs: Any) -> None:
         super().__init__(
@@ -528,15 +529,13 @@ class PostgreQueryBuilder(QueryBuilder):
         querystring = super(PostgreQueryBuilder, self).get_sql(
               with_alias, subquery, **kwargs
         )
-        with_namespace = False
-        if self._update_table and self.from_:
-            with_namespace = True
 
         querystring += self._on_conflict_sql(**kwargs)
         querystring += self._on_conflict_action_sql(**kwargs)
 
         if self._returns:
-            querystring += self._returning_sql(with_namespace=with_namespace, **kwargs)
+            kwargs['with_namespace'] = self._update_table and self.from_
+            querystring += self._returning_sql(**kwargs)
         return querystring
 
 
@@ -579,9 +578,31 @@ class MSSQLQueryBuilder(QueryBuilder):
         except ValueError:
             raise QueryException("TOP value must be an integer")
 
+    @builder
+    def fetch_next(self, limit: int) -> "MSSQLQueryBuilder":
+        # Overridden to provide a more domain-specific API for T-SQL users
+        self._limit = limit
+
+    def _offset_sql(self) -> str:
+        return " OFFSET {offset} ROWS".format(offset=self._offset or 0)
+
+    def _limit_sql(self) -> str:
+        return " FETCH NEXT {limit} ROWS ONLY".format(limit=self._limit)
+
+    def _apply_pagination(self, querystring: str) -> str:
+        # Note: Overridden as MSSQL specifies offset before the fetch next limit
+        if self._limit is not None or self._offset:
+            # Offset has to be present if fetch next is specified in a MSSQL query
+            querystring += self._offset_sql()
+
+        if self._limit is not None:
+            querystring += self._limit_sql()
+
+        return querystring
+
     def get_sql(self, *args: Any, **kwargs: Any) -> str:
         return super().get_sql(
-              *args, groupby_alias=False, **kwargs
+            *args, groupby_alias=False, **kwargs
         )
 
     def _top_sql(self) -> str:
