@@ -573,6 +573,7 @@ class QueryBuilder(Selectable, Term):
     QUOTE_CHAR = '"'
     SECONDARY_QUOTE_CHAR = "'"
     ALIAS_QUOTE_CHAR = None
+    QUERY_ALIAS_QUOTE_CHAR = None
 
     def __init__(
           self,
@@ -593,10 +594,12 @@ class QueryBuilder(Selectable, Term):
         self._with = []
         self._selects = []
         self._force_indexes = []
+        self._use_indexes = []
         self._columns = []
         self._values = []
         self._distinct = False
         self._ignore = False
+        self._for_update = False
 
         self._wheres = None
         self._prewheres = None
@@ -827,10 +830,22 @@ class QueryBuilder(Selectable, Term):
             elif isinstance(t, str):
                 self._force_indexes.append(Index(t))
 
+    @builder
+    def use_index(self, term: Union[str, Index], *terms: Union[str, Index]) -> "QueryBuilder":
+        for t in (term, *terms):
+            if isinstance(t, Index):
+                self._use_indexes.append(t)
+            elif isinstance(t, str):
+                self._use_indexes.append(Index(t))
+
     @builder
     def distinct(self) -> "QueryBuilder":
         self._distinct = True
 
+    @builder
+    def for_update(self) -> "QueryBuilder":
+        self._for_update = True
+
     @builder
     def ignore(self) -> "QueryBuilder":
         self._ignore = True
@@ -1142,7 +1157,6 @@ class QueryBuilder(Selectable, Term):
 
     def get_sql(self, with_alias: bool = False, subquery: bool = False, **kwargs: Any) -> str:
         self._set_kwargs_defaults(kwargs)
-
         if not (
               self._selects
               or self._insert_table
@@ -1237,6 +1251,9 @@ class QueryBuilder(Selectable, Term):
         if self._force_indexes:
             querystring += self._force_index_sql(**kwargs)
 
+        if self._use_indexes:
+            querystring += self._use_index_sql(**kwargs)
+
         if self._joins:
             querystring += " " + " ".join(
                   join.get_sql(**kwargs) for join in self._joins
@@ -1259,27 +1276,38 @@ class QueryBuilder(Selectable, Term):
         if self._orderbys:
             querystring += self._orderby_sql(**kwargs)
 
+        querystring = self._apply_pagination(querystring)
+
+        if self._for_update:
+            querystring += self._for_update_sql()
+
+        if subquery:
+            querystring = "({query})".format(query=querystring)
+
+        if with_alias:
+            kwargs['alias_quote_char'] = (self.ALIAS_QUOTE_CHAR
+                                          if self.QUERY_ALIAS_QUOTE_CHAR is None
+                                          else self.QUERY_ALIAS_QUOTE_CHAR)
+            return format_alias_sql(querystring, self.alias, **kwargs)
+
+        return querystring
+
+    def _apply_pagination(self, querystring: str) -> str:
         if self._limit is not None:
             querystring += self._limit_sql()
 
         if self._offset:
             querystring += self._offset_sql()
 
-        if subquery:
-            querystring = "({query})".format(query=querystring)
-
-        if with_alias:
-            return format_alias_sql(querystring, self.alias, **kwargs)
-
         return querystring
 
     def _with_sql(self, **kwargs: Any) -> str:
         return "WITH " + ",".join(
-              clause.name
-              + " AS ("
-              + clause.get_sql(subquery=False, with_alias=False, **kwargs)
-              + ") "
-              for clause in self._with
+            clause.name
+            + " AS ("
+            + clause.get_sql(subquery=False, with_alias=False, **kwargs)
+            + ") "
+            for clause in self._with
         )
 
     def _distinct_sql(self, **kwargs: Any) -> str:
@@ -1290,6 +1318,14 @@ class QueryBuilder(Selectable, Term):
 
         return distinct
 
+    def _for_update_sql(self) -> str:
+        if self._for_update:
+            for_update = ' FOR UPDATE'
+        else:
+            for_update = ''
+
+        return for_update
+
     def _select_sql(self, **kwargs: Any) -> str:
         return "SELECT {distinct}{select}".format(
               distinct=self._distinct_sql(**kwargs),
@@ -1358,6 +1394,11 @@ class QueryBuilder(Selectable, Term):
               indexes=",".join(index.get_sql(**kwargs) for index in self._force_indexes),
         )
 
+    def _use_index_sql(self, **kwargs: Any) -> str:
+        return " USE INDEX ({indexes})".format(
+              indexes=",".join(index.get_sql(**kwargs) for index in self._use_indexes),
+        )
+
     def _prewhere_sql(self, quote_char: Optional[str] = None, **kwargs: Any) -> str:
         return " PREWHERE {prewhere}".format(
               prewhere=self._prewheres.get_sql(
